@@ -16,7 +16,7 @@
 #  Boston, MA  02111-1307, USA.
 #
 #  Jabber
-#  Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
+#  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 #
 ##############################################################################
 
@@ -55,12 +55,12 @@ a clean way of defining Namespaces for XML::Stream to use when connecting.
 =head1 EXAMPLES
 
 
-  $myNamespace = XML::Stream::Namespace->new("mynamspace");
+  $myNamespace = new XML::Stream::Namespace("mynamspace");
   $myNamespace->SetXMLNS("http://www.mynamespace.org/xmlns");
   $myNamespace->SetAttributes(foo=>"bar",
                               bob=>"vila");
 
-  $stream = XML::Stream->new;
+  $stream = new XML::Stream;
   $stream->Connect(name=>"foo.bar.org",
                    port=>1234,
                    namespace=>"foo:bar",
@@ -85,22 +85,19 @@ a clean way of defining Namespaces for XML::Stream to use when connecting.
 Written by Ryan Eatmon in February 2000
 Idea By Thomas Charron in January of 2000 for http://etherx.jabber.org/streams/
 
-Currently maintained by Darian Anthony Patrick.
-
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
-
-This module licensed under the LGPL, version 2.1.
+This module is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
+require 5.003;
 use strict;
-use warnings;
 use Carp;
-use vars qw( $VERSION );
+use vars qw($VERSION);
 
-$VERSION = "1.23_07";
+$VERSION = "1.18";
 
 sub new
 {
@@ -189,6 +186,3 @@ sub GetStream
     
   return $string;
 }
-
-1;
-
