@@ -16,7 +16,7 @@
 #  Boston, MA  02111-1307, USA.
 #
 #  Jabber
-#  Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
+#  Copyright (C) 1998-2002 The Jabber Team http://jabber.org/
 #
 ##############################################################################
 
@@ -129,22 +129,16 @@ would be:
 
 By Ryan Eatmon in June 2002 for http://jabber.org/
 
-Currently maintained by Darian Anthony Patrick.
-
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
-
-This module licensed under the LGPL, version 2.1.
+This module is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
-use strict;
-use warnings;
-use vars qw( $VERSION $LOADED );
+use vars qw($VERSION);
 
-$VERSION = "1.23_07";
-$LOADED = 1;
+$VERSION = "1.18";
 
 sub new
 {
@@ -223,7 +217,7 @@ sub add_child
 {
     my $self = shift;
 
-    my $child = XML::Stream::Node->new(@_);
+    my $child = new XML::Stream::Node(@_);
     push(@{$self->{CHILDREN}},$child);
     return $child;
 }
@@ -248,7 +242,7 @@ sub remove_child
 sub add_cdata
 {
     my $self = shift;
-    my $child = XML::Stream::Node->new("__xmlstream__:node:cdata");
+    my $child = new XML::Stream::Node("__xmlstream__:node:cdata");
     foreach my $cdata (@_)
     {
         push(@{$child->{CHILDREN}},$cdata);
@@ -403,7 +397,7 @@ sub copy
 {
     my $self = shift;
 
-    my $new_node = XML::Stream::Node->new();
+    my $new_node = new XML::Stream::Node();
     $new_node->set_tag($self->get_tag());
     $new_node->put_attrib($self->attrib());
 
@@ -411,7 +405,7 @@ sub copy
     {
         if ($child->get_tag() eq "__xmlstream__:node:cdata")
         {
-            $new_node->add_cdata($child->children());
+            $new_node->add_cdata($self->get_cdata());
         }
         else
         {
@@ -444,7 +438,7 @@ sub _handle_element
 
     $self->debug(2,"Node: _handle_element: sid($sid) sax($sax) tag($tag) att(",%att,")");
 
-    my $node = XML::Stream::Node->new($tag);
+    my $node = new XML::Stream::Node($tag);
     $node->put_attrib(%att);
 
     $self->debug(2,"Node: _handle_element: check(",$#{$self->{SIDS}->{$sid}->{node}},")");
