@@ -16,7 +16,7 @@
 #  Boston, MA  02111-1307, USA.
 #
 #  Jabber
-#  Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
+#  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 #
 ##############################################################################
 
@@ -44,35 +44,31 @@ package XML::Stream::Parser;
 
 By Ryan Eatmon in January of 2001 for http://jabber.org/
 
-Currently maintained by Darian Anthony Patrick.
-
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
-
-This module licensed under the LGPL, version 2.1.
+This module is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
+#use 5.008_000;
 use strict;
-use warnings;
 use vars qw( $VERSION );
 
-$VERSION = "1.23_07";
+BEGIN {
+    if( $] >= 5.008 )
+    {
+        eval("use open ':utf8';");
+    }
+}
 
-use Scalar::Util qw(weaken);
-
-use XML::Stream::Tree;
-use XML::Stream::Node;
-use XML::Stream::Tools;
+$VERSION = "1.18";
 
 sub new
 {
-    my $class = shift;
-
     my $self = { };
 
-    bless($self, $class);
+    bless($self);
 
     my %args;
     while($#_ >= 0) { $args{ lc pop(@_) } = pop(@_); }
@@ -86,27 +82,81 @@ sub new
     $args{nonblocking} = 0 unless exists($args{nonblocking});
 
     $self->{NONBLOCKING} = delete($args{nonblocking});
-    XML::Stream::Tools::setup_debug($self, %args); 
+
+    $self->{DEBUGTIME} = 0;
+    $self->{DEBUGTIME} = $args{debugtime} if exists($args{debugtime});
+
+    $self->{DEBUGLEVEL} = 0;
+    $self->{DEBUGLEVEL} = $args{debuglevel} if exists($args{debuglevel});
+
+    $self->{DEBUGFILE} = "";
+
+    if (exists($args{debugfh}) && ($args{debugfh} ne ""))
+    {
+        $self->{DEBUGFILE} = $args{debugfh};
+        $self->{DEBUG} = 1;
+    }
+
+    if ((exists($args{debugfh}) && ($args{debugfh} eq "")) ||
+        (exists($args{debug}) && ($args{debug} ne "")))
+        {
+        $self->{DEBUG} = 1;
+        if (lc($args{debug}) eq "stdout")
+        {
+            $self->{DEBUGFILE} = new FileHandle(">&STDERR");
+            $self->{DEBUGFILE}->autoflush(1);
+        }
+        else
+        {
+            if (-e $args{debug})
+            {
+                if (-w $args{debug})
+                {
+                    $self->{DEBUGFILE} = new FileHandle(">$args{debug}");
+                    $self->{DEBUGFILE}->autoflush(1);
+                }
+                else
+                {
+                    print "WARNING: debug file ($args{debug}) is not writable by you\n";
+                    print "         No debug information being saved.\n";
+                    $self->{DEBUG} = 0;
+                }
+            }
+            else
+            {
+                $self->{DEBUGFILE} = new FileHandle(">$args{debug}");
+                if (defined($self->{DEBUGFILE}))
+                {
+                    $self->{DEBUGFILE}->autoflush(1);
+                }
+                else
+                {
+                    print "WARNING: debug file ($args{debug}) does not exist \n";
+                    print "         and is not writable by you.\n";
+                    print "         No debug information being saved.\n";
+                    $self->{DEBUG} = 0;
+                }
+            }
+        }
+    }
 
     $self->{SID} = exists($args{sid}) ? $args{sid} : "__xmlstream__:sid";
 
     $self->{STYLE} = (exists($args{style}) ? lc($args{style}) : "tree");
     $self->{DTD} = (exists($args{dtd}) ? lc($args{dtd}) : 0);
 
-    my $weak = $self;
-    weaken $weak;
     if ($self->{STYLE} eq "tree")
     {
-        $self->{HANDLER}->{startDocument} = sub{ $weak->startDocument(@_); };
-        $self->{HANDLER}->{endDocument} = sub{ $weak->endDocument(@_); };
+        $self->{HANDLER}->{startDocument} = sub{ $self->startDocument(@_); };
+        $self->{HANDLER}->{endDocument} = sub{ $self->endDocument(@_); };
         $self->{HANDLER}->{startElement} = sub{ &XML::Stream::Tree::_handle_element(@_); };
         $self->{HANDLER}->{endElement} = sub{ &XML::Stream::Tree::_handle_close(@_); };
         $self->{HANDLER}->{characters} = sub{ &XML::Stream::Tree::_handle_cdata(@_); };
     }
     elsif ($self->{STYLE} eq "node")
     {
-        $self->{HANDLER}->{startDocument} = sub{ $weak->startDocument(@_); };
-        $self->{HANDLER}->{endDocument} = sub{ $weak->endDocument(@_); };
+        $self->{HANDLER}->{startDocument} = sub{ $self->startDocument(@_); };
+        $self->{HANDLER}->{endDocument} = sub{ $self->endDocument(@_); };
         $self->{HANDLER}->{startElement} = sub{ &XML::Stream::Node::_handle_element(@_); };
         $self->{HANDLER}->{endElement} = sub{ &XML::Stream::Node::_handle_close(@_); };
         $self->{HANDLER}->{characters} = sub{ &XML::Stream::Node::_handle_cdata(@_); };
@@ -226,9 +276,7 @@ sub parse
             $self->{XML} = substr($self->{XML},length($self->{CNAME}->[$self->{CURR}])+3,length($self->{XML})-length($self->{CNAME}->[$self->{CURR}])-3);
 
             $self->{PARSING} = 0 if ($self->{NONBLOCKING} == 1);
-            my $weak = $self;
-            weaken $weak;
-            &{$self->{HANDLER}->{endElement}}($weak, $weak->{CNAME}->[$weak->{CURR}]);
+            &{$self->{HANDLER}->{endElement}}($self,$self->{CNAME}->[$self->{CURR}]);
             $self->{PARSING} = 1 if ($self->{NONBLOCKING} == 1);
 
             $self->{CURR}--;
@@ -272,13 +320,11 @@ sub parse
             {
             }
 
-            my $weak = $self;
-            weaken $weak;
-            &{$self->{HANDLER}->{startElement}}($weak, $name,%attribs);
+            &{$self->{HANDLER}->{startElement}}($self,$name,%attribs);
 
             if($empty == 1)
             {
-                &{$self->{HANDLER}->{endElement}}($weak, $name);
+                &{$self->{HANDLER}->{endElement}}($self,$name);
             }
             else
             {
@@ -345,12 +391,10 @@ sub attribution
             $ids = $id1;
             $id = "\'";
         }
-        else {
-            if((($id2 < $id1) && ($id1 == -1)) || ($id2 != -1))
-            {
-                $ids = $id2;
-                $id = "\"";
-            }
+        if((($id2 < $id1) && ($id1 == -1)) || ($id2 != -1))
+        {
+            $ids = $id2;
+            $id = "\"";
         }
 
         my $nextid = index($str,$id,$ids+1);
@@ -387,7 +431,14 @@ sub parsefile
     my $self = shift;
     my $fileName = shift;
 
-    open(FILE,"<",$fileName);
+    if( $] >= 5.008 )
+    {
+        open(FILE,"<:utf8",$fileName);
+    }
+    else
+    {
+        open(FILE,"<",$fileName);
+    }
     my $file;
     while(<FILE>) { $file .= $_; }
     $self->parse($file);
