@@ -16,7 +16,7 @@
 #  Boston, MA  02111-1307, USA.
 #
 #  Jabber
-#  Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
+#  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 #
 ##############################################################################
 
@@ -44,21 +44,17 @@ package XML::Stream::Parser::DTD;
 
 By Ryan Eatmon in February of 2001 for http://jabber.org/
 
-Currently maintained by Darian Anthony Patrick.
-
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
-
-This module licensed under the LGPL, version 2.1.
+This module is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
 use strict;
-use warnings;
-use vars qw( $VERSION );
+use vars qw($VERSION);
 
-$VERSION = "1.23_07";
+$VERSION = "1.18";
 
 sub new
 {
@@ -83,13 +79,10 @@ sub new
     $self->{ENTITY}->{"&apos;"} = "'";
     $self->{ENTITY}->{"&amp;"} = "&";
 
-use Scalar::Util qw(weaken);
-    my $weak = $self;
-    weaken $weak;
-    $self->{HANDLER}->{startDocument} = sub{ $weak->startDocument(@_); };
-    $self->{HANDLER}->{endDocument} = sub{ $weak->endDocument(@_); };
-    $self->{HANDLER}->{startElement} = sub{ $weak->startElement(@_); };
-    $self->{HANDLER}->{endElement} = sub{ $weak->endElement(@_); };
+    $self->{HANDLER}->{startDocument} = sub{ $self->startDocument(@_); };
+    $self->{HANDLER}->{endDocument} = sub{ $self->endDocument(@_); };
+    $self->{HANDLER}->{startElement} = sub{ $self->startElement(@_); };
+    $self->{HANDLER}->{endElement} = sub{ $self->endElement(@_); };
 
     $self->{STYLE} = "debug";
 
