@@ -16,7 +16,7 @@
 #  Boston, MA  02111-1307, USA.
 #
 #  Jabber
-#  Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
+#  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 #
 ##############################################################################
 
@@ -63,23 +63,16 @@ Larry and Clark.
 
 By Ryan Eatmon in March 2001 for http://jabber.org/
 
-Currently maintained by Darian Anthony Patrick.
-
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
-
-This module licensed under the LGPL, version 2.1.
+This module is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
-use 5.008;
-use strict;
-use warnings;
-use vars qw( $VERSION $LOADED );
+use vars qw($VERSION);
 
-$VERSION = "1.23_07";
-$LOADED = 1;
+$VERSION = "1.18";
 
 ##############################################################################
 #
