@@ -16,7 +16,7 @@
 #  Boston, MA  02111-1307, USA.
 #
 #  Jabber
-#  Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
+#  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 #
 ##############################################################################
 
@@ -28,12 +28,11 @@
 ##############################################################################
 package XML::Stream::XPath::Op;
 
-use 5.008;
+use 5.006_001;
 use strict;
-use warnings;
-use vars qw( $VERSION );
+use vars qw($VERSION);
 
-$VERSION = "1.23_07";
+$VERSION = "1.18";
 
 sub new
 {
@@ -106,7 +105,6 @@ sub new
     my $proto = shift;
     my $self = $proto->allocate("POSITION","");
     $self->{POS} = shift;
-
     return $self;
 }
 
@@ -160,7 +158,7 @@ sub isValid
     my @valid_elems;
     foreach my $elem (@elems)
     {
-        my $tmp_ctxt = XML::Stream::XPath::Value->new($elem);
+        my $tmp_ctxt = new XML::Stream::XPath::Value($elem);
         $tmp_ctxt->in_context(1);
         if ($self->{OP}->isValid(\$tmp_ctxt))
         {
@@ -371,7 +369,7 @@ sub isValid
     my $self = shift;
     my $ctxt = shift;
 
-    my $tmp_ctxt = XML::Stream::XPath::Value->new();
+    my $tmp_ctxt = new XML::Stream::XPath::Value();
     $tmp_ctxt->setList($$ctxt->getList());
     $tmp_ctxt->in_context(0);
     
@@ -446,7 +444,7 @@ sub isValid
     my $self = shift;
     my $ctxt = shift;
 
-    my $tmp_ctxt = XML::Stream::XPath::Value->new();
+    my $tmp_ctxt = new XML::Stream::XPath::Value();
     $tmp_ctxt->setList($$ctxt->getList());
     $tmp_ctxt->in_context(0);
     
@@ -665,9 +663,9 @@ sub isValid
 
     foreach my $elem (@elems)
     {
-        my $tmp_ctxt_l = XML::Stream::XPath::Value->new($elem);
+        my $tmp_ctxt_l = new XML::Stream::XPath::Value($elem);
         $tmp_ctxt_l->in_context(1);
-        my $tmp_ctxt_r = XML::Stream::XPath::Value->new($elem);
+        my $tmp_ctxt_r = new XML::Stream::XPath::Value($elem);
         $tmp_ctxt_r->in_context(1);
 
         my $opl = $self->{OP_L}->isValid(\$tmp_ctxt_l);
@@ -814,7 +812,7 @@ sub function_not
     my @valid_elems;
     foreach my $elem (@elems)
     {
-        my $tmp_ctxt = XML::Stream::XPath::Value->new($elem);
+        my $tmp_ctxt = new XML::Stream::XPath::Value($elem);
         $tmp_ctxt->in_context(1);
         if (!($args[0]->isValid(\$tmp_ctxt)))
         {
