@@ -16,19 +16,18 @@
 #  Boston, MA  02111-1307, USA.
 #
 #  Jabber
-#  Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
+#  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 #
 ##############################################################################
 
 package XML::Stream::XPath::Query;
 
-use 5.008;
+use 5.006_001;
 use strict;
-use warnings;
 use Carp;
-use vars qw( $VERSION );
+use vars qw($VERSION);
 
-$VERSION = "1.23_07";
+$VERSION = "1.18";
 
 sub new
 {
@@ -112,7 +111,7 @@ sub getOp
             {
                 $$pos = $pos_start;
                 my $temp_ident = $self->getNextIdentifier($pos);
-                $ret_op = XML::Stream::XPath::NodeOp->new($temp_ident,"0");
+                $ret_op = new XML::Stream::XPath::NodeOp($temp_ident,"0");
             }
             elsif ($token eq "/")
             {
@@ -120,20 +119,20 @@ sub getOp
                 {
                     $$pos++;
                     my $temp_ident = $self->getNextIdentifier($pos);
-                    $ret_op = XML::Stream::XPath::AllOp->new($temp_ident);
+                    $ret_op = new XML::Stream::XPath::AllOp($temp_ident);
                 }
                 else
                 {
                     my $temp_ident = $self->getNextIdentifier($pos);
                     if ($temp_ident ne "")
                     {
-                        $ret_op = XML::Stream::XPath::NodeOp->new($temp_ident,($pos_start == 0 ? "1" : "0"));
+                        $ret_op = new XML::Stream::XPath::NodeOp($temp_ident,($pos_start == 0 ? "1" : "0"));
                     }
                 }
             }
             elsif ($token eq "\@")
             {
-                $ret_op = XML::Stream::XPath::AttributeOp->new($self->getNextIdentifier($pos));
+                $ret_op = new XML::Stream::XPath::AttributeOp($self->getNextIdentifier($pos));
             }
             elsif ($token eq "]")
             {
@@ -151,7 +150,7 @@ sub getOp
             elsif (($token eq "\"") || ($token eq "\'"))
             {
                 $$pos = index($self->{QUERY},$token,$token_start);
-                $ret_op = XML::Stream::XPath::Op->new("LITERAL",substr($self->{QUERY},$token_start,$$pos-$token_start));
+                $ret_op = new XML::Stream::XPath::Op("LITERAL",substr($self->{QUERY},$token_start,$$pos-$token_start));
                 $$pos++;
             }
             elsif ($token eq " ")
@@ -166,7 +165,7 @@ sub getOp
                         confess("Invalid 'and' operation");
                         return;
                     }
-                    $ret_op = XML::Stream::XPath::AndOp->new($self->{OPS}->[$#{$self->{OPS}}],$tmp_op);
+                    $ret_op = new XML::Stream::XPath::AndOp($self->{OPS}->[$#{$self->{OPS}}],$tmp_op);
                     $in_context = 0;
                     pop(@{$self->{OPS}});
                 }
@@ -179,7 +178,7 @@ sub getOp
                         confess("Invalid 'or' operation");
                         return;
                     }
-                    $ret_op = XML::Stream::XPath::OrOp->new($self->{OPS}->[$#{$self->{OPS}}],$tmp_op);
+                    $ret_op = new XML::Stream::XPath::OrOp($self->{OPS}->[$#{$self->{OPS}}],$tmp_op);
                     $in_context = 0;
                     pop(@{$self->{OPS}});
                 }
@@ -198,19 +197,19 @@ sub getOp
                     my $val = $self->getNextIdentifier($pos);
                     if ($val =~ /^\d+$/)
                     {
-                        $ret_op = XML::Stream::XPath::PositionOp->new($val);
+                        $ret_op = new XML::Stream::XPath::PositionOp($val);
                         $$pos++;
                     }
                     else
                     {
                         $$pos = $pos_start + 1;
-                        $ret_op = XML::Stream::XPath::ContextOp->new($self->getOp($pos,$token));
+                        $ret_op = new XML::Stream::XPath::ContextOp($self->getOp($pos,$token));
                     }
                 }
                 else
                 {
                     $$pos = $pos_start + 1;
-                    $ret_op = XML::Stream::XPath::ContextOp->new($self->getOp($pos,$token));
+                    $ret_op = new XML::Stream::XPath::ContextOp($self->getOp($pos,$token));
                 }
             }
             elsif ($token eq "(")
@@ -229,7 +228,7 @@ sub getOp
                 {
                     confess("Undefined function \"$function\"");
                 }
-                $ret_op = XML::Stream::XPath::FunctionOp->new($function);
+                $ret_op = new XML::Stream::XPath::FunctionOp($function);
 
                 my $op_pos = $#{$self->{OPS}} + 1;
 
@@ -270,7 +269,7 @@ sub getOp
                 {
                     $tmp_op = $self->getOp($pos);
                 }
-                $ret_op = XML::Stream::XPath::EqualOp->new($self->{OPS}->[$#{$self->{OPS}}],$tmp_op);
+                $ret_op = new XML::Stream::XPath::EqualOp($self->{OPS}->[$#{$self->{OPS}}],$tmp_op);
                 pop(@{$self->{OPS}});
             }
             elsif ($token eq "!")
@@ -286,7 +285,7 @@ sub getOp
                 {
                     $tmp_op = $self->getOp($pos);
                 }
-                $ret_op = XML::Stream::XPath::NotEqualOp->new($self->{OPS}->[$#{$self->{OPS}}],$tmp_op);
+                $ret_op = new XML::Stream::XPath::NotEqualOp($self->{OPS}->[$#{$self->{OPS}}],$tmp_op);
                 pop(@{$self->{OPS}});
             }
             else
@@ -345,7 +344,7 @@ sub execute
     my $self = shift;
     my $root = shift;
 
-    my $ctxt = XML::Stream::XPath::Value->new($root);
+    my $ctxt = new XML::Stream::XPath::Value($root);
 
     foreach my $op (@{$self->{OPS}})
     {
