@@ -16,18 +16,17 @@
 #  Boston, MA  02111-1307, USA.
 #
 #  Jabber
-#  Copyright (C) 1998-2004 Jabber Software Foundation http://jabber.org/
+#  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 #
 ##############################################################################
 
 package XML::Stream::XPath::Value;
 
-use 5.008;
+use 5.006_001;
 use strict;
-use warnings;
-use vars qw( $VERSION );
+use vars qw($VERSION);
 
-$VERSION = "1.23_07";
+$VERSION = "1.18";
 
 sub new
 {
